
#include <LiquidCrystal.h>
#include <dht11.h>
#include <SPI.h>
#include <Ethernet.h>

dht11 DHT11;   // new class dht11 named DHT11, temperature reading is in DHT11.temperature, humidity in DHT11.humidity 

float tset = 20;   //starting wanted temperature when the system turns on
float hmax = 55;     //starting maximum wanted humidity when the system turns on

#define DHT11PIN 2   //pin 2 is the input for dht11 sensor
#define VENTOUT 3    //pin 3 is the output for the fan   
//#define HEATOUT 11    //pin 11 is the output for the heater  
const int HEATOUT =  A5;

int pos = 0; 
byte mac[] = { 0x90, 0xA2, 0xDA, 0x0D, 0xA5, 0xFE };   //physical mac address
byte ip[] = { 169, 254, 115, 218 };                      // ip in lan (that's what you need to use in your browser. ("192.168.1.178")
byte gateway[] = {}; //{ 10, 129, 0, 1 };                   // internet access via router 192.178.1.1
byte subnet[] = { 255, 255, 0, 0 };                  //subnet mask
EthernetServer server(80);                             //server port     
String readString;

// select the pins used on the LCD panel
LiquidCrystal lcd(8, 9, A1, A2, A3, A4);

// define some values used by the panel and buttons

int lcd_key     = 0;
int adc_key_in  = 0;
#define btnRIGHT  0
#define btnUP     1
#define btnDOWN   2
#define btnLEFT   3
#define btnSELECT 4
#define btnNONE   5

// read the buttons function

int read_LCD_buttons()
{
 adc_key_in = analogRead(0);      // read the value from the sensor 
 // my buttons when read are centered at these valies: 0, 144, 329, 504, 741
 // we add approx 50 to those values and check to see if we are close
 if (adc_key_in > 1000) return btnNONE; // We make this the 1st option for speed reasons since it will be the most likely result
 // For V1.1 us this threshold
 if (adc_key_in < 50)   return btnRIGHT;  
 if (adc_key_in < 250)  return btnUP; 
 if (adc_key_in < 450)  return btnDOWN; 
 if (adc_key_in < 650)  return btnLEFT; 
 if (adc_key_in < 850)  return btnSELECT;  

 return btnNONE;  // when all others fail, return this...
}

// timer values for reading the dht11 sensor every 2s

unsigned long previousMillis = 0;        // will store last time dht11 was read

// constants won't change :
const long interval = 2000;           // interval for reading dht11 sensor (every 2000ms)

void setup() {
digitalWrite(HEATOUT, LOW);
Serial.begin(9600);
   while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }


  // start the Ethernet connection and the server:
  Ethernet.begin(mac, ip); //gateway, subnet);
  server.begin();
  Serial.print("server is at ");
  Serial.println(Ethernet.localIP());

pinMode(VENTOUT, OUTPUT);
pinMode(HEATOUT, OUTPUT);

lcd.begin(16, 2);              // start the library

}

void loop() {

  // Create a client connection
  EthernetClient client = server.available();

   if (client) {
    while (client.connected()) {   
      if (client.available()) {
        char c = client.read();
     
        //read char by char HTTP request
        if (readString.length() < 100) {
          //store characters to string
          readString += c;
          //Serial.print(c);
         }

         //if HTTP request has ended
         if (c == '\n') {          
           Serial.println(readString); //print to serial monitor for debuging
     
           client.println("HTTP/1.1 200 OK"); //send new page
           client.println("Content-Type: text/html");
           client.println();     
           client.println("<HTML>");
           client.println("<HEAD>");
           client.println("<meta name='apple-mobile-web-app-capable' content='yes' />");
           client.println("<meta name='apple-mobile-web-app-status-bar-style' content='black-translucent' />");
           client.println("<link rel='stylesheet' type='text/css' href='http://randomnerdtutorials.com/ethernetcss.css' />");
           client.println("<TITLE>Regulacija i pracenje temperature i vlage</TITLE>");
           client.println("</HEAD>");
           client.println("<BODY>");
           client.println("<H1>Regulacija i pracenje temperature i vlage</H1>");
           client.println("<hr />");
           client.println("<br />");
//
           client.print("<p style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>Trenutna temperatura = ");
           client.println((int)DHT11.temperature);
           //client.print("</strong></span><h style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'><sup>o</sup>C</strong></span></h></p>");
           //client.println("<h>");
           client.println("<br>");
           client.print("<p style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>Zeljena temperatura = ");
          client.println((int)tset);
          //client.print("</strong></span><h style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'><sup>o</sup>C</strong></span></h></p>");
          //client.println("<h>"); 
          
         // client.print("<p style='text-align: center;'>&nbsp;</p>");
          client.print("<p style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>Trenutna vlaga = ");
          client.println((int)DHT11.humidity);
          //client.print("</strong></span><h style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>%</h></p>");
          // client.println("<h>");
          //client.println("<br>");
          
         // client.print("<p style='text-align: center;'>&nbsp;</p>");
          client.print("<p style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>Maksimalna vlaga = ");
          client.println((int)hmax);
             client.println("<br />");  
                client.println("<br />");  
          //client.print("</strong></span><h style='text-align: center;'><span style='color: #0000ff;'><strong style='font-size: large;'>%</h></p>");
          // client.println("<h>");
             //
           client.println("<br />");  
           client.println("<a href=\"/?button1on\"\">Povecaj temperaturu</a>");
           client.println("<a href=\"/?button1off\"\">Smanji temperaturu</a><br />");   
           client.println("<br />");     
           client.println("<br />"); 
           client.println("<a href=\"/?button2on\"\">Povecaj max. vlagu</a>");
           client.println("<a href=\"/?button2off\"\">Smanji max. vlagu</a>"); 
           client.println("<br />"); 
           client.println("</BODY>");
           client.println("</HTML>");
     
           delay(1);
           //stopping client
           client.stop();
           //controls the Arduino if you press the buttons
           if (readString.indexOf("?button1on") >0){
              
               tset = tset + 2;
               if(tset>35) {
                tset=10;
                }
           }
          //  readString="";  
           if (readString.indexOf("?button1off") >0){
               
               tset = tset - 2;
               if(tset<10) {
                tset=35;
                }
           }
           // readString="";  

          if (readString.indexOf("?button2on") >0){
               hmax=hmax+5;
               if(hmax>100) {
                hmax=10;
                }
           }
          //  readString="";  
           if (readString.indexOf("?button2off") >0){
               hmax=hmax-5;
                if(hmax<10) {
                hmax=100;
                }
           }
                      
            readString="";   //clearing string for next read
           
         }
       }
    }
}
  
unsigned long currentMillis = millis();  
  
  if (currentMillis - previousMillis >= interval) {
    
    previousMillis = currentMillis;

   int chk = DHT11.read(DHT11PIN);    //reading the sensor every 2000 ms
   
}

lcd.setCursor(0,0);         //set cursor at the beginning of the 1st line   
lcd.print("Tnow");
lcd.setCursor(5,0);  
lcd.print(DHT11.temperature);

lcd.setCursor(0,1);          
lcd.print("Tset");
lcd.setCursor(5,1);  
lcd.print((int)tset);

lcd.setCursor(8,0);           
lcd.print("Hnow");
lcd.setCursor(13,0);  
lcd.print(DHT11.humidity);
lcd.setCursor(15,0);  
lcd.print("%");

lcd.setCursor(8,1);           
lcd.print("Hmax");
lcd.setCursor(13,1);  
lcd.print((int)hmax);
lcd.setCursor(15,1);  
lcd.print("%");

 lcd_key = read_LCD_buttons();  // read the buttons

 switch (lcd_key)               // depending on which button was pushed, we perform an action
 {
  
  case btnSELECT:
     {
     lcd.setCursor(0,1);         //set cursor at the beginning of the 1st line   
lcd.print("Regulation off     ");


while (lcd_key != btnLEFT)
{
  digitalWrite(VENTOUT, LOW);
  digitalWrite(HEATOUT, LOW);
  lcd_key = read_LCD_buttons();
  }
  lcd.setCursor(0,1);   //set cursor at the beginning of the 1st line   
lcd.print("                ");  
lcd.print("Tset");
lcd.setCursor(5,1);  
lcd.print((int)tset);
  
     break;
     }
   case btnLEFT:
     {
         break;
     }
   
   case btnUP:
     {
     tset=tset + 0.05;
     if (tset>35) {tset=10;}
     break;
     }
   case btnDOWN:
     {
    tset=tset - 0.2;
    if (tset<10) {tset=35;}
     break;
     }
   case btnRIGHT:
     {
if(hmax>100) { hmax = 10; }
    hmax = hmax + 0.1;
       
lcd.setCursor(8,1);           
lcd.print("Hmax");
lcd.setCursor(13,1);  
lcd.print((int)hmax);
lcd.setCursor(15,1);  
lcd.print("%");
          
     break;
     }
     case btnNONE:
     {
     break;
     }
 }

 if((int)DHT11.humidity>hmax) {
digitalWrite(VENTOUT, HIGH);   // fan is turned on if humidity exceeds wanted maximum humidity
               
    }
 if((int)DHT11.temperature>tset) {
digitalWrite(VENTOUT, HIGH);   // fan is turned on if wanted temperature Tset is lower than current temperature Tnow
               
    }    
 else if ((int)DHT11.humidity<hmax) {   digitalWrite(VENTOUT, LOW);  }
 if((int)DHT11.temperature<(tset-1)) {
digitalWrite(HEATOUT, HIGH);   // heating is turned on if wanted temperature Tset is higher than current temperature Tnow
               
    }    
else {
  
  digitalWrite(HEATOUT, LOW);
  
  }

}

 




